@@ -1,6 +1,7 @@
 use serde_json::json;
 use std::fmt::{self, Formatter};
 use std::str::FromStr;
+use log::*;
 use std::time::Duration;
 
 use anyhow::{anyhow, Context};
@@ -320,7 +321,7 @@ where
         body: vec![],
     };
 
-    let resp = req.send("get")?;
+    let resp = req.send("GET")?;
 
     match resp.into_json::<Token>()? {
         ResponseValue::Okay(t) => Ok(t),
@@ -349,10 +350,16 @@ where
         .into_bytes(),
     };
 
-    let resp = req.send("post")?;
+    let resp = req.send("POST")?;
     match resp.into_json::<R>()? {
-        ResponseValue::Okay(t) => Ok(t),
-        ResponseValue::Failure(f) => Err(crate::Error::Other(anyhow!(f.to_string()))),
+        ResponseValue::Okay(t) => {
+            trace!("The code was redeemed for a token (or token-compatible value)");
+            Ok(t)
+        }
+        ResponseValue::Failure(f) => {
+            warn!("The code could not be redeemed.");
+            Err(crate::Error::Other(anyhow!(f.to_string())))
+        }
     }
 }
 
