@@ -29,7 +29,7 @@ pub fn send(req: &Request) -> Result<Response, Error> {
             .context("Failed to parse the URL to be sent in a Webmention sending request.")
             .map_err(crate::Error::Other)?,
     };
-    let resp = req.send("post")?;
+    let resp = req.send("POST")?;
 
     match resp.status_code {
         204 | 200 | 201 => {
