@@ -3,7 +3,7 @@ use std::cmp::PartialEq;
 
 /// Represents the state of a Webmention for a client or a server.
 #[derive(Clone, Debug, Serialize, Deserialize, Eq)]
-#[serde(rename_all = "lowercase")]
+#[serde(untagged, rename_all = "lowercase")]
 pub enum Status {
     /// Used to highlight that a stored Webmention or a response about a Webmention has
     /// been rejected by a remote endpoint or the implementation of a server is informing a client
@@ -57,8 +57,11 @@ pub struct Request {
 }
 
 /// Represents a outgoing resonse from an endpoint for a Webmention.
-#[derive(Clone, Default, Debug, Serialize, Deserialize)]
+#[derive(Clone, Debug, Serialize, Deserialize)]
 pub struct Response {
+    /// The originating endpoint.
+    pub endpoint: url::Url,
+
     /// The resulting status of a Webmention.
     pub status: Status,
 
